@@ -21,7 +21,7 @@ board_initialize.github <- function(board,
                                     token = NULL,
                                     repo = NULL,
                                     path = "",
-                                    branch = "master",
+                                    branch = NULL,
                                     overwrite = FALSE,
                                     host = "https://api.github.com",
                                     ...) {
@@ -41,21 +41,26 @@ board_initialize.github <- function(board,
   board$path <- if (!is.null(path) && nchar(path) > 0) paste0(path, "/") else ""
   board$branch <- branch
   board$host <- host
+  board$main <- "master"
 
   # check repo exists
   check_exists <- httr::GET(github_url(board, branch = NULL), github_headers(board))
   if (httr::http_error(check_exists)) {
-    stop("The repo '", board$repo, "' does not exist or can't be accessed: ", httr::content(check_exists)$message)
+    stop("The repo '", board$repo, "' does not exist or can't be accessed: ", httr::content(check_exists, encoding = "UTF-8")$message)
   }
 
   branches <- tryCatch(github_branches(board), error = function(e) e)
   if ("error" %in% class(branches) && grepl("^Git Repository is empty", branches$message)) {
-    github_update_index(board, "", "initialize repo", operation = "initialize", branch = "master")
+    github_update_index(board, "", "initialize repo", operation = "initialize", branch = "main")
     branches <- github_branches(board)
   }
 
-  if (!identical(branch, "master") && !branch %in% branches) {
-    github_branches_create(board, branch, "master")
+  if ("main" %in% branches) {
+    board$main <- "main"
+  }
+
+  if (!identical(branch, NULL) && !branch %in% branches) {
+    github_branches_create(board, branch, board$main)
   }
 
   board
@@ -68,8 +73,8 @@ github_update_temp_index <- function(board, path, commit, operation, name = NULL
   sha <- NULL
   index <- list()
   if (!httr::http_error(response)) {
-    sha <- httr::content(response)$sha
-    content <- httr::content(response)
+    sha <- httr::content(response, encoding = "UTF-8")$sha
+    content <- httr::content(response, encoding = "UTF-8")
 
     # API returns contents when size < 1mb
     if (!is.null(content$content)) {
@@ -78,7 +83,7 @@ github_update_temp_index <- function(board, path, commit, operation, name = NULL
     else {
       response <- httr::GET(content$download_url, github_headers(board))
       if (!httr::http_error(response)) {
-        index <- board_manifest_load(httr::content(response))
+        index <- board_manifest_load(httr::content(response, encoding = "UTF-8"))
       }
     }
   }
@@ -133,18 +138,23 @@ github_update_index <- function(board, path, commit, operation, name = NULL, met
                         github_headers(board), encode = "json")
 
   if (httr::http_error(response)) {
-    stop("Failed to update data.txt file: ", httr::content(response))
+    stop("Failed to update data.txt file: ", httr::content(response, encoding = "UTF-8"))
   }
 }
 
 github_delete_release <- function(board, release_tag) {
   response <- httr::GET(github_url(board, branch = NULL, paste0("/releases/tags/", release_tag)), github_headers(board))
   if (!httr::http_error(response)) {
-    release_id <- httr::content(response)$id
+    release_id <- httr::content(response, encoding = "UTF-8")$id
     response <- httr::DELETE(github_url(board, branch = NULL, paste0("/releases/", release_id)), github_headers(board))
     if (httr::http_error(response)) {
       pin_log("Failed to delete release ", release_id)
     }
+
+    response <- httr::DELETE(github_url(board, branch = NULL, paste0("/git/refs/tags/", release_tag)), github_headers(board))
+    if (httr::http_error(response)) {
+      pin_log("Failed to delete tag ", release_tag)
+    }
   }
 }
 
@@ -152,7 +162,7 @@ github_create_release <- function(board, name) {
   index_url <- github_url(board, branch = NULL, "/commits/", board$branch)
   response <- httr::GET(index_url, github_headers(board))
   version <- "initial"
-  if (!httr::http_error(response)) version <- substr(httr::content(response)$sha, 1, 7)
+  if (!httr::http_error(response)) version <- substr(httr::content(response, encoding = "UTF-8")$sha, 1, 7)
 
   release_url <- github_url(board, branch = NULL, "/releases")
 
@@ -178,9 +188,9 @@ github_create_release <- function(board, name) {
     body = release,
     github_headers(board), encode = "json")
 
-  if (httr::http_error(response)) stop("Failed to create release '", release$tag_name, "' for '", name, "': ", httr::content(response)$message)
+  if (httr::http_error(response)) stop("Failed to create release '", release$tag_name, "' for '", name, "': ", httr::content(response, encoding = "UTF-8")$message)
 
-  httr::content(response)
+  httr::content(response, encoding = "UTF-8")
 }
 
 github_upload_release <- function(board, release, name, file, file_path) {
@@ -194,9 +204,9 @@ github_upload_release <- function(board, release, name, file, file_path) {
     http_utils_progress("up", size = file.info(normalizePath(file_path))$size)
   )
 
-  if (httr::http_error(response)) stop("Failed to upload asset '", file, "': ", httr::content(response)$message)
+  if (httr::http_error(response)) stop("Failed to upload asset '", file, "': ", httr::content(response, encoding = "UTF-8")$message)
 
-  httr::content(response)$browser_download_url
+  httr::content(response, encoding = "UTF-8")$url
 }
 
 github_upload_content <- function(board, name, file, file_path, commit, sha, branch) {
@@ -213,7 +223,7 @@ github_upload_content <- function(board, name, file, file_path, commit, sha, bra
                         ),
                         github_headers(board), encode = "json",
                         http_utils_progress("up", size = file.info(normalizePath(file_path))$size))
-  upload <- httr::content(response)
+  upload <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to upload ", file, " response: ", upload)
@@ -233,7 +243,7 @@ github_upload_blob <- function(board, file, file_path, commit) {
                          ),
                          github_headers(board), encode = "json",
                          http_utils_progress("up", size = file.info(normalizePath(file_path))$size))
-  upload <- httr::content(response)
+  upload <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to upload ", file, " response: ", upload)
@@ -254,7 +264,7 @@ github_create_tree <- function(board, tree_files, base_sha) {
                          ),
                          github_headers(board), encode = "json",
                          http_utils_progress("up"))
-  upload <- httr::content(response)
+  upload <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to create tree, response: ", upload)
@@ -278,7 +288,7 @@ github_create_commit <- function(board, tree_sha, base_sha, commit) {
                          ),
                          github_headers(board), encode = "json",
                          http_utils_progress("up"))
-  upload <- httr::content(response)
+  upload <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to create commit, response: ", upload)
@@ -300,7 +310,7 @@ github_update_head <- function(board, branch, commit_sha) {
                          ),
                          github_headers(board), encode = "json",
                          http_utils_progress("up"))
-  upload <- httr::content(response)
+  upload <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to update branch, reponse: ", upload)
@@ -314,7 +324,7 @@ github_refs_head <- function(board, branch) {
   ref_url <- github_url(board, branch = NULL, paste0("/git/ref/heads/", branch))
   response <- httr::GET(ref_url, github_headers(board))
 
-  reference <- httr::content(response)
+  reference <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response)) {
     pin_log("Failed to retrieve branch, reponse: ", response)
@@ -394,7 +404,12 @@ board_pin_create.github <- function(board, path, name, metadata, ...) {
 
     datatxt <- suppressWarnings(yaml::read_yaml(file_path, eval.expr = FALSE))
 
+    datatxt$filenames <- as.list(datatxt$path)
+
     datatxt$path <- sapply(datatxt$path, function(e) { if(e %in% names(release_map)) release_map[[e]] else e })
+
+    names(datatxt$filenames) <- datatxt$path
+
     yaml::write_yaml(datatxt, file_path)
   }
 
@@ -404,7 +419,7 @@ board_pin_create.github <- function(board, path, name, metadata, ...) {
 
   # update local index
   if (update_index) {
-    index_path <- paste0(board$path, name)
+    index_path <- name
 
     index <- github_update_temp_index(board, index_path, commit, operation = "create",
                                             name = name, metadata = metadata, branch = branch)
@@ -425,10 +440,10 @@ board_pin_find.github <- function(board, text, ...) {
                       github_headers(board))
 
   if (!httr::http_error(result)) {
-    content <- httr::content(result)
+    content <- httr::content(result, encoding = "UTF-8")
     if (is.null(content$content)) {
       result <- httr::GET(content$download_url, github_headers(board))
-      content <- httr::content(result)
+      content <- httr::content(result, encoding = "UTF-8")
     }
     else {
       content <- rawToChar(base64enc::base64decode(content$content))
@@ -452,7 +467,7 @@ board_pin_find.github <- function(board, text, ...) {
                                github_headers(board))
 
     if (!httr::http_error(result_single)) {
-      local_path <- pin_download(httr::content(result_single)$download_url,
+      local_path <- pin_download(httr::content(result_single, encoding = "UTF-8")$download_url,
                                  result$name,
                                  board$name,
                                  headers = github_headers(board),
@@ -478,9 +493,9 @@ github_url <- function(board, branch = board$branch, ...) {
 
 github_branches <- function(board) {
   response <- httr::GET(github_url(board, "/git", "/refs", branch = NULL), github_headers(board))
-  if (httr::http_error(response)) stop(httr::content(response))
+  if (httr::http_error(response)) stop(httr::content(response, encoding = "UTF-8"))
 
-  httr::content(response) %>%
+  httr::content(response, encoding = "UTF-8") %>%
     sapply(function(e) gsub("refs/heads/", "", e$ref))
 }
 
@@ -490,10 +505,10 @@ github_branch <- function(board, branch) {
   response <- httr::GET(github_url(board, "/git", "/refs", branch = NULL), github_headers(board))
 
   if (httr::http_error(response)) {
-    stop("Failed to retrieve branches ", as.character(httr::content(response)))
+    stop("Failed to retrieve branches ", as.character(httr::content(response, encoding = "UTF-8")))
   }
 
-  branch_object <- Filter(function(e) identical(e$ref, reference), httr::content(response))
+  branch_object <- Filter(function(e) identical(e$ref, reference), httr::content(response, encoding = "UTF-8"))
 
   if (length(branch_object) != 1) stop("Failed to retrieve branch ", branch)
 
@@ -513,7 +528,7 @@ github_branches_create <- function(board, new_branch, base_branch) {
     github_headers(board), encode = "json")
 
   if (httr::http_error(response)) {
-    stop("Failed to create branch ", new_branch, " ", as.character(httr::content(response)))
+    stop("Failed to create branch ", new_branch, " ", as.character(httr::content(response, encoding = "UTF-8")))
   }
 }
 
@@ -536,7 +551,7 @@ github_download_files <- function(index, temp_path, board) {
     pin_log("retrieving ", file$download_url)
 
     if (is.list(file) && identical(file$type, "dir")) {
-      sub_index <- httr::GET(file$url, github_headers(board), http_utils_progress()) %>% httr::content()
+      sub_index <- httr::GET(file$url, github_headers(board), http_utils_progress()) %>% httr::content(encoding = "UTF-8")
       github_download_files(sub_index, file.path(temp_path, file$name), board)
     }
     else {
@@ -560,20 +575,30 @@ board_pin_get.github <- function(board, name, extract = NULL, version = NULL, ..
   local_path <- pin_download(base_url, name, board$name, headers = github_headers(board), subpath = subpath)
 
   if (file.exists(file.path(local_path, "data.txt"))) {
-    index_path <- pin_manifest_download(local_path)
+    index_path <- pin_manifest_download(local_path, namemap = TRUE)
 
-    for (file in index_path) {
+    for (file_idx in seq_along(index_path)) {
+      file <- index_path[file_idx]
       file_url <- file
       headers <- github_headers(board)
+      file_name <- if (!identical(names(index_path), NULL) && nchar(names(index_path)[file_idx]) > 0) names(index_path)[file_idx] else NULL
 
       if (grepl("^http://|^https://", file)) {
-        # retrieving releases fails if auth headers are specified
-        headers <- NULL
+        # manually move authorization to url due to https://github.com/octokit/rest.js/issues/967
+        file_url <- paste0(file_url, "?access_token=", github_auth(board))
+        headers <- httr::add_headers(Accept = "application/octet-stream")
       }
       else {
         file_url <- github_raw_url(board, branch = branch, board$path, name, "/", file)
       }
-      pin_download(file_url, name, board$name, headers = headers, extract = identical(extract, TRUE), subpath = subpath)
+
+      pin_download(file_url,
+                   name,
+                   board$name,
+                   headers = headers,
+                   extract = identical(extract, TRUE),
+                   subpath = subpath,
+                   download_name = file_name)
     }
 
     local_path
@@ -582,7 +607,7 @@ board_pin_get.github <- function(board, name, extract = NULL, version = NULL, ..
     base_url <- github_raw_url(board, branch = branch, board$path, name)
     result <- httr::GET(base_url, github_headers(board))
 
-    index <- httr::content(result)
+    index <- httr::content(result, encoding = "UTF-8")
 
     if (httr::http_error(result))
       stop("Failed to retrieve ", name, " from ", board$repo, ": ", index$message)
@@ -608,7 +633,7 @@ board_pin_remove.github <- function(board, name, ...) {
   base_url <- github_content_url(board, name, branch = NULL)
   result <- httr::GET(paste0(base_url, "?ref=", board$branch), github_headers(board))
 
-  index <- httr::content(result)
+  index <- httr::content(result, encoding = "UTF-8")
 
   if (httr::http_error(result))
     stop("Failed to retrieve ", name, " from ", board$repo, ": ", index$message)
@@ -624,7 +649,7 @@ board_pin_remove.github <- function(board, name, ...) {
       branch = board$branch
     ), github_headers(board), encode = "json")
 
-    deletion <- httr::content(response)
+    deletion <- httr::content(response, encoding = "UTF-8")
 
     if (httr::http_error(response))
       stop("Failed to delete ", name, " from ", board$repo, ": ", deletion$message)
@@ -650,7 +675,7 @@ board_pin_versions.github <- function(board, name, ...) {
                                    "&path=", path),
                       github_headers(board))
 
-  commits <- httr::content(response)
+  commits <- httr::content(response, encoding = "UTF-8")
 
   if (httr::http_error(response))
     stop("Failed to retrieve commits from ", board$repo, ": ", commits$message)
