@@ -39,12 +39,21 @@ rsconnect_token_initialize <- function(board) {
     board$server_name <- accounts$server[1]
   }
 
+  if (!any(accounts$server == board$server_name)) {
+    registered <- accounts$server[!grepl("^shinyapps.io", accounts$server)]
+    stop("The server ", board$server_name, " is not registered, available servers: ", paste0(registered, collapse = ", "))
+  }
+
   if (is.null(board$account)) board$account <- accounts[accounts$server == board$server_name,]$name
 
   if (length(board$account) != 1) {
     stop("Multiple accounts (", paste(board$account, collapse = ", "), ") are associated to this server, please specify the correct account parameter in board_register().")
   }
 
+  if (!any(accounts$name == board$account)) {
+    stop("The account ", board$account, " is not registered, available accounts: ", paste0(accounts$name, collapse = ", "))
+  }
+
   # always use the url from rstudio to ensure redirects work properly even when the full path is not specified
   board$server <- gsub("/__api__", "", deps$server_info(board$server_name)$url)
 
@@ -96,7 +105,11 @@ rsconnect_token_post <- function(board, path, content, encode) {
                                  content_type,
                                  content_file)
 
-  jsonlite::fromJSON(result$content)
+  tryCatch({
+    jsonlite::fromJSON(result$content)
+  }, error = function(e) {
+    stop("Failed to parse result: ", result$content)
+  })
 }
 
 # nocov end
